@@ -152,7 +152,8 @@ def deploy(settings_path=None, **settings_patches):
             # We wanna preserve pyc/pyo files in our remote
             # Remove *.pyc, *.pyo, *.py[co] in ignore patterns and append "logs/" in the ignore file
             local(
-                'sed -i.bak -e \'/^\*\.py[c|o]$/d;/^\*\.py\[co\]$/d;$a\\\nlogs\/\' .gitignore && rm -rf .gitignore.bak'
+                'sed -i.bak -e \'/^\*\.py[c|o]$/d;/^\*\.py\[co\]$/d;$a\\\nlogs\/\nvenv\/\' %s && rm -rf %s.bak' %
+                ('.gitignore', '.gitignore')
             )
 
             # Check source code first
